@@ -2,9 +2,9 @@
  * (C) Copyright 2007 Bastien Nocera <hadess@hadess.net>
  *
  * Glow code from libwnck/libwnck/tasklist.c:
- * Copyright (C) 2001 Havoc Pennington
- * Copyright (C) 2003 Kim Woelders
- * Copyright (C) 2003 Red Hat, Inc.
+ * Copyright © 2001 Havoc Pennington
+ * Copyright © 2003 Kim Woelders
+ * Copyright © 2003 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -25,7 +25,7 @@
 #ifndef __TOTEM_GLOW_BUTTON_H__
 #define __TOTEM_GLOW_BUTTON_H__
 
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
@@ -41,7 +41,7 @@ typedef struct _TotemGlowButtonClass {
   gpointer __bla[4];
 } TotemGlowButtonClass;
 
-GType		totem_glow_button_get_type	(void);
+GType		totem_glow_button_get_type	(void) G_GNUC_CONST;
 
 GtkWidget *	totem_glow_button_new		(void);
 void		totem_glow_button_set_glow	(TotemGlowButton *button, gboolean glow);
