@@ -32,12 +32,12 @@
 #include <gmodule.h>
 #include <gdk-pixbuf/gdk-pixdata.h>
 #include <gdk/gdkkeysyms.h>
-#include <gconf/gconf-client.h>
 #include <unistd.h>
 #include <math.h>
 
-#include "bacon-video-widget.h"
+#include "backend/bacon-video-widget.h"
 #include "totem-plugin.h"
+#include "totem-dirs.h"
 #include "totem-interface.h"
 #include "totem.h"
 #include "totem-cmml-parser.h"
@@ -63,6 +63,8 @@
 #define ICON_SCALE_RATIO 2
 
 typedef struct {
+	TotemObject	*totem;
+	TotemEditChapter *edit_chapter;
 	GtkWidget	*tree;
 	GtkWidget	*add_button,
 			*remove_button,
@@ -80,20 +82,11 @@ typedef struct {
 	gchar		*cmml_mrl;
 	gboolean	autoload;
 	GCancellable	*cancellable[2];
-	GConfClient	*gconf;
+	GSettings	*settings;
 	guint		autoload_handle_id;
 } TotemChaptersPluginPrivate;
 
-typedef struct {
-	TotemPlugin			 parent;
-	TotemObject			*totem;
-	TotemEditChapter		*edit_chapter;
-	TotemChaptersPluginPrivate	*priv;
-} TotemChaptersPlugin;
-
-typedef struct {
-	TotemPluginClass		parent_class;
-} TotemChaptersPluginClass;
+TOTEM_PLUGIN_REGISTER (TOTEM_TYPE_CHAPTERS_PLUGIN, TotemChaptersPlugin, totem_chapters_plugin)
 
 enum {
 	CHAPTERS_PIXBUF_COLUMN = 0,
@@ -104,11 +97,6 @@ enum {
 	CHAPTERS_N_COLUMNS
 };
 
-G_MODULE_EXPORT GType register_totem_plugin (GTypeModule *module);
-GType totem_chapters_plugin_get_type (void) G_GNUC_CONST;
-static gboolean impl_activate (TotemPlugin *plugin, TotemObject *totem, GError **error);
-static void impl_deactivate (TotemPlugin *plugin, TotemObject *totem);
-static void totem_chapters_plugin_finalize (GObject *object);
 static void totem_file_opened_async_cb (TotemObject *totem, const gchar *uri, TotemChaptersPlugin *plugin);
 static void totem_file_opened_result_cb (gpointer data, gpointer user_data);
 static void totem_file_closed_cb (TotemObject *totem, TotemChaptersPlugin *plugin);
@@ -124,7 +112,7 @@ static void show_chapter_edit_dialog (TotemChaptersPlugin *plugin);
 static void save_chapters_result_cb (gpointer data, gpointer user_data);
 static GList * get_chapters_list (TotemChaptersPlugin *plugin);
 static gboolean show_popup_menu (TotemChaptersPlugin *plugin, GdkEventButton *event);
-static void gconf_autoload_changed_cb (GConfClient *gconf, guint cnx_id, GConfEntry *entry, TotemChaptersPlugin	*plugin);
+static void autoload_changed_cb (GSettings *settigs, const gchar *key, TotemChaptersPlugin *plugin);
 static void load_chapters_from_file (const gchar *uri, gboolean from_dialog, TotemChaptersPlugin *plugin);
 static void set_no_data_visible (gboolean visible, gboolean show_buttons, TotemChaptersPlugin *plugin);
 
@@ -142,34 +130,6 @@ void popup_goto_action_cb (GtkAction *action, TotemChaptersPlugin *plugin);
 void load_button_clicked_cb (GtkButton *button, TotemChaptersPlugin *plugin);
 void continue_button_clicked_cb (GtkButton *button, TotemChaptersPlugin *plugin);
 
-TOTEM_PLUGIN_REGISTER (TotemChaptersPlugin, totem_chapters_plugin)
-
-static void
-totem_chapters_plugin_class_init (TotemChaptersPluginClass *klass)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	TotemPluginClass *plugin_class = TOTEM_PLUGIN_CLASS (klass);
-
-	g_type_class_add_private (klass, sizeof (TotemChaptersPluginPrivate));
-
-	object_class->finalize = totem_chapters_plugin_finalize;
-
-	plugin_class->activate = impl_activate;
-	plugin_class->deactivate = impl_deactivate;
-}
-
-static void
-totem_chapters_plugin_init (TotemChaptersPlugin *plugin)
-{
-	plugin->priv = TOTEM_CHAPTERS_PLUGIN_GET_PRIVATE (plugin);
-}
-
-static void
-totem_chapters_plugin_finalize (GObject *object)
-{
-	G_OBJECT_CLASS (totem_chapters_plugin_parent_class)->finalize (object);
-}
-
 static GdkPixbuf *
 get_chapter_pixbuf (GdkPixbuf *src)
 {
@@ -211,7 +171,6 @@ add_chapter_to_the_list (gpointer	data,
 	TotemChaptersPlugin	*plugin;
 	GdkPixbuf		*pixbuf;
 	GtkTreeIter		iter;
-	GtkWidget		*tree;
 	GtkTreeStore		*store;
 	TotemCmmlClip		*clip;
 	gchar			*text, *start, *tip;
@@ -220,7 +179,6 @@ add_chapter_to_the_list (gpointer	data,
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (user_data));
 
 	plugin = TOTEM_CHAPTERS_PLUGIN (user_data);
-	tree = plugin->priv->tree;
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (plugin->priv->tree)));
 	clip = ((TotemCmmlClip *) data);
 
@@ -254,7 +212,7 @@ add_chapter_to_the_list (gpointer	data,
 static void
 add_chapter_to_the_list_new (TotemChaptersPlugin	*plugin,
 			     const gchar		*title,
-			     gint64			time)
+			     gint64			_time)
 {
 	GdkPixbuf	*pixbuf;
 	GtkTreeIter	iter, cur_iter, res_iter;
@@ -266,7 +224,7 @@ add_chapter_to_the_list_new (TotemChaptersPlugin	*plugin,
 
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 	g_return_if_fail (title != NULL);
-	g_return_if_fail (time >= 0);
+	g_return_if_fail (_time >= 0);
 
 	store = gtk_tree_view_get_model (GTK_TREE_VIEW (plugin->priv->tree));
 	valid = gtk_tree_model_get_iter_first (store, &cur_iter);
@@ -276,7 +234,7 @@ add_chapter_to_the_list_new (TotemChaptersPlugin	*plugin,
 				    CHAPTERS_TIME_PRIV_COLUMN, &cur_time,
 				    -1);
 
-		if (time < cur_time && time > prev_time)
+		if (_time < cur_time && _time > prev_time)
 			break;
 
 		iter_count += 1;
@@ -287,7 +245,7 @@ add_chapter_to_the_list_new (TotemChaptersPlugin	*plugin,
 	}
 
 	/* prepare tooltip data */
-	start = totem_cmml_convert_msecs_to_str (time);
+	start = totem_cmml_convert_msecs_to_str (_time);
 	tip = CHAPTER_TOOLTIP (title, start);
 
 	/* insert clip into the sidebar list at proper position */
@@ -304,7 +262,7 @@ add_chapter_to_the_list_new (TotemChaptersPlugin	*plugin,
 			    CHAPTERS_TOOLTIP_COLUMN, tip,
 			    CHAPTERS_PIXBUF_COLUMN, pixbuf,
 			    CHAPTERS_TITLE_PRIV_COLUMN, title,
-			    CHAPTERS_TIME_PRIV_COLUMN, time,
+			    CHAPTERS_TIME_PRIV_COLUMN, _time,
 			    -1);
 
 	g_object_unref (pixbuf);
@@ -315,7 +273,7 @@ add_chapter_to_the_list_new (TotemChaptersPlugin	*plugin,
 
 static gboolean
 check_available_time (TotemChaptersPlugin	*plugin,
-		      gint64			time)
+		      gint64			_time)
 {
 	GtkTreeModel	*store;
 	GtkTreeIter	iter;
@@ -332,10 +290,10 @@ check_available_time (TotemChaptersPlugin	*plugin,
 				    CHAPTERS_TIME_PRIV_COLUMN, &cur_time,
 				    -1);
 
-		if (cur_time == time)
+		if (cur_time == _time)
 			return FALSE;
 
-		if (cur_time > time)
+		if (cur_time > _time)
 			return TRUE;
 
 		valid = gtk_tree_model_iter_next (store, &iter);
@@ -367,8 +325,8 @@ totem_file_opened_result_cb (gpointer	data,
 			g_free (adata);
 			return;
 		} else
-			totem_action_error (_("Error while reading file with chapters"),
-					    adata->error, plugin->totem);
+			totem_action_error (plugin->priv->totem, _("Error while reading file with chapters"),
+					    adata->error);
 	}
 
 	if (adata->is_exists && adata->from_dialog) {
@@ -428,8 +386,8 @@ totem_file_closed_cb (TotemObject		*totem,
 
 	gtk_tree_store_clear (store);
 
-	if (G_UNLIKELY (plugin->edit_chapter != NULL))
-		gtk_widget_destroy (GTK_WIDGET (plugin->edit_chapter));
+	if (G_UNLIKELY (plugin->priv->edit_chapter != NULL))
+		gtk_widget_destroy (GTK_WIDGET (plugin->priv->edit_chapter));
 
 	if (G_UNLIKELY (plugin->priv->last_frame != NULL))
 		g_object_unref (G_OBJECT (plugin->priv->last_frame));
@@ -454,13 +412,13 @@ chapter_edit_dialog_response_cb (GtkDialog		*dialog,
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 
 	if (response != GTK_RESPONSE_OK) {
-		gtk_widget_destroy (GTK_WIDGET (plugin->edit_chapter));
+		gtk_widget_destroy (GTK_WIDGET (plugin->priv->edit_chapter));
 
 		if (plugin->priv->last_frame != NULL)
 			g_object_unref (G_OBJECT (plugin->priv->last_frame));
 
 		if (plugin->priv->was_played)
-			totem_action_play (plugin->totem);
+			totem_action_play (plugin->priv->totem);
 		return;
 	}
 
@@ -475,10 +433,10 @@ chapter_edit_dialog_response_cb (GtkDialog		*dialog,
 		g_object_unref (G_OBJECT (plugin->priv->last_frame));
 
 	g_free (title);
-	gtk_widget_destroy (GTK_WIDGET (plugin->edit_chapter));
+	gtk_widget_destroy (GTK_WIDGET (plugin->priv->edit_chapter));
 
 	if (plugin->priv->was_played)
-		totem_action_play (plugin->totem);
+		totem_action_play (plugin->priv->totem);
 }
 
 static void
@@ -521,7 +479,7 @@ finish_chapter_edit (GtkCellRendererText	*renderer,
 	GtkTreeModel		*store;
 	GtkTreeIter		iter;
 	gchar			*time_str, *tip, *new_title, *old_title;
-	gint64			time;
+	gint64			_time;
 
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (user_data));
 	g_return_if_fail (new_text != NULL);
@@ -534,7 +492,7 @@ finish_chapter_edit (GtkCellRendererText	*renderer,
 		return;
 
 	gtk_tree_model_get (store, &iter,
-			    CHAPTERS_TIME_PRIV_COLUMN, &time,
+			    CHAPTERS_TIME_PRIV_COLUMN, &_time,
 			    CHAPTERS_TITLE_PRIV_COLUMN, &old_title,
 			    -1);
 
@@ -543,7 +501,7 @@ finish_chapter_edit (GtkCellRendererText	*renderer,
 		return;
 	}
 
-	time_str = totem_cmml_convert_msecs_to_str (time);
+	time_str = totem_cmml_convert_msecs_to_str (_time);
 	new_title = CHAPTER_TITLE (new_text, time_str);
 	tip = CHAPTER_TOOLTIP (new_text, time_str);
 
@@ -566,50 +524,50 @@ show_chapter_edit_dialog (TotemChaptersPlugin	*plugin)
 {
 	GtkWindow		*main_window;
 	BaconVideoWidget	*bvw;
-	gint64			time;
+	gint64			_time;
 
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 
-	if (G_UNLIKELY (plugin->edit_chapter != NULL)) {
-		gtk_window_present (GTK_WINDOW (plugin->edit_chapter));
+	if (G_UNLIKELY (plugin->priv->edit_chapter != NULL)) {
+		gtk_window_present (GTK_WINDOW (plugin->priv->edit_chapter));
 		return;
 	}
 
-	main_window = totem_get_main_window (plugin->totem);
-	plugin->priv->was_played = totem_is_playing (plugin->totem);
-	totem_action_pause (plugin->totem);
+	main_window = totem_get_main_window (plugin->priv->totem);
+	plugin->priv->was_played = totem_is_playing (plugin->priv->totem);
+	totem_action_pause (plugin->priv->totem);
 
 	/* adding a new one, check if it's time available */
-	g_object_get (G_OBJECT (plugin->totem), "current-time", &time, NULL);
-	if (G_UNLIKELY (!check_available_time (plugin, time))) {
+	g_object_get (G_OBJECT (plugin->priv->totem), "current-time", &_time, NULL);
+	if (G_UNLIKELY (!check_available_time (plugin, _time))) {
 		totem_interface_error_blocking (_("Chapter with the same time already exists"),
-						_("Try another name or remove an existing chapter"),
+						_("Try another name or remove an existing chapter."),
 						main_window);
 		g_object_unref (main_window);
 		if (plugin->priv->was_played)
-			totem_action_play (plugin->totem);
+			totem_action_play (plugin->priv->totem);
 		return;
 	}
-	plugin->priv->last_time = time;
+	plugin->priv->last_time = _time;
 
 	/* capture frame */
-	bvw = BACON_VIDEO_WIDGET (totem_get_video_widget (plugin->totem));
+	bvw = BACON_VIDEO_WIDGET (totem_get_video_widget (plugin->priv->totem));
 	plugin->priv->last_frame = bacon_video_widget_get_current_frame (bvw);
 	g_object_add_weak_pointer (G_OBJECT (plugin->priv->last_frame), (gpointer *) &plugin->priv->last_frame);
 	g_object_unref (bvw);
 
 	/* create chapter-edit dialog */
-	plugin->edit_chapter = TOTEM_EDIT_CHAPTER (totem_edit_chapter_new ());
-	g_object_add_weak_pointer (G_OBJECT (plugin->edit_chapter), (gpointer *) &(plugin->edit_chapter));
+	plugin->priv->edit_chapter = TOTEM_EDIT_CHAPTER (totem_edit_chapter_new ());
+	g_object_add_weak_pointer (G_OBJECT (plugin->priv->edit_chapter), (gpointer *) &(plugin->priv->edit_chapter));
 
-	g_signal_connect (G_OBJECT (plugin->edit_chapter), "delete-event",
+	g_signal_connect (G_OBJECT (plugin->priv->edit_chapter), "delete-event",
 			  G_CALLBACK (gtk_widget_destroy), NULL);
-	g_signal_connect (G_OBJECT (plugin->edit_chapter), "response",
+	g_signal_connect (G_OBJECT (plugin->priv->edit_chapter), "response",
 			  G_CALLBACK (chapter_edit_dialog_response_cb), plugin);
 
-	gtk_window_set_transient_for (GTK_WINDOW (plugin->edit_chapter),
+	gtk_window_set_transient_for (GTK_WINDOW (plugin->priv->edit_chapter),
 				      main_window);
-	gtk_widget_show (GTK_WIDGET (plugin->edit_chapter));
+	gtk_widget_show (GTK_WIDGET (plugin->priv->edit_chapter));
 
 	g_object_unref (main_window);
 }
@@ -633,19 +591,15 @@ chapter_selection_changed_cb (GtkTreeSelection		*tree_selection,
 }
 
 static void
-gconf_autoload_changed_cb (GConfClient		*gconf,
-			   guint		cnx_id,
-			   GConfEntry		*entry,
-			   TotemChaptersPlugin	*plugin)
+autoload_changed_cb (GSettings			*settings,
+		     const gchar		*key,
+		     TotemChaptersPlugin	*plugin)
 {
-	g_return_if_fail (GCONF_IS_CLIENT (gconf));
-	g_return_if_fail (entry != NULL);
+	g_return_if_fail (G_IS_SETTINGS (settings));
+	g_return_if_fail (key != NULL);
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 
-	if (G_LIKELY (entry->value != NULL))
-		plugin->priv->autoload = gconf_value_get_bool (entry->value);
-	else
-		plugin->priv->autoload = TRUE;
+	plugin->priv->autoload = g_settings_get_boolean (settings, key);
 }
 
 static void
@@ -760,8 +714,8 @@ save_chapters_result_cb (gpointer	data,
 	plugin = TOTEM_CHAPTERS_PLUGIN (adata->user_data);
 
 	if (G_UNLIKELY (!adata->successful && !g_cancellable_is_cancelled (adata->cancellable))) {
-		totem_action_error (_("Error while writing file with chapters"),
-				    adata->error, plugin->totem);
+		totem_action_error (plugin->priv->totem, _("Error while writing file with chapters"),
+				    adata->error);
 		gtk_widget_set_sensitive (plugin->priv->save_button, TRUE);
 	}
 
@@ -780,7 +734,7 @@ get_chapters_list (TotemChaptersPlugin	*plugin)
 	GtkTreeModel	*store;
 	GtkTreeIter	iter;
 	gchar		*title;
-	gint64		time;
+	gint64		_time;
 	GdkPixbuf	*pixbuf;
 	gboolean	valid;
 
@@ -792,10 +746,10 @@ get_chapters_list (TotemChaptersPlugin	*plugin)
 	while (valid) {
 		gtk_tree_model_get (store, &iter,
 				    CHAPTERS_TITLE_PRIV_COLUMN, &title,
-				    CHAPTERS_TIME_PRIV_COLUMN, &time,
+				    CHAPTERS_TIME_PRIV_COLUMN, &_time,
 				    CHAPTERS_PIXBUF_COLUMN, &pixbuf,
 				    -1);
-		clip = totem_cmml_clip_new (title, NULL, time, pixbuf);
+		clip = totem_cmml_clip_new (title, NULL, _time, pixbuf);
 		list = g_list_prepend (list, clip);
 
 		g_free (title);
@@ -885,10 +839,9 @@ save_button_clicked_cb (GtkButton		*button,
 				   (gpointer *) &(plugin->priv->cancellable[1]));
 
 	if (G_UNLIKELY (totem_cmml_write_file_async (data) < 0)) {
-		totem_action_error (_("Error occurred while saving chapters"),
-				    _("Please check you rights and free space"), plugin->totem);
+		totem_action_error (plugin->priv->totem, _("Error occurred while saving chapters"),
+		                    _("Please check you have permission to write to the folder containing the movie."));
 		g_free (data);
-		g_object_unref (plugin->priv->cancellable);
 	} else
 		gtk_widget_set_sensitive (plugin->priv->save_button, FALSE);
 }
@@ -902,23 +855,23 @@ tree_view_row_activated_cb (GtkTreeView			*tree_view,
 	GtkTreeModel	*store;
 	GtkTreeIter	iter;
 	gboolean	seekable;
-	gint64		time;
+	gint64		_time;
 
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 	g_return_if_fail (GTK_IS_TREE_VIEW (tree_view));
 	g_return_if_fail (path != NULL);
 
 	store = gtk_tree_view_get_model (tree_view);
-	seekable = totem_is_seekable (plugin->totem);
+	seekable = totem_is_seekable (plugin->priv->totem);
 	if (!seekable) {
 		g_warning ("chapters: unable to seek stream!");
 		return;
 	}
 
 	gtk_tree_model_get_iter (store, &iter, path);
-	gtk_tree_model_get (store, &iter, CHAPTERS_TIME_PRIV_COLUMN, &time, -1);
+	gtk_tree_model_get (store, &iter, CHAPTERS_TIME_PRIV_COLUMN, &_time, -1);
 
-	totem_action_seek_time (plugin->totem, time, TRUE);
+	totem_action_seek_time (plugin->priv->totem, _time, TRUE);
 }
 
 gboolean
@@ -950,7 +903,7 @@ tree_view_key_press_cb (GtkTreeView		*tree_view,
 	/* Special case some shortcuts */
 	if (event->state != 0) {
 		if ((event->state & GDK_CONTROL_MASK) &&
-		    event->keyval == GDK_a) {
+		    event->keyval == GDK_KEY_a) {
 			gtk_tree_selection_select_all (selection);
 			return TRUE;
 		}
@@ -967,7 +920,7 @@ tree_view_key_press_cb (GtkTreeView		*tree_view,
 	    || (event->state & GDK_MOD5_MASK)))
 		return FALSE;
 
-	if (event->keyval == GDK_Delete) {
+	if (event->keyval == GDK_KEY_Delete) {
 		if (gtk_tree_selection_count_selected_rows (selection) > 0)
 			remove_button_clicked_cb (GTK_BUTTON (plugin->priv->remove_button), plugin);
 		return TRUE;
@@ -1015,12 +968,12 @@ load_button_clicked_cb (GtkButton		*button,
 
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 
-	plugin->priv->was_played = totem_is_playing (plugin->totem);
-	totem_action_pause (plugin->totem);
+	plugin->priv->was_played = totem_is_playing (plugin->priv->totem);
+	totem_action_pause (plugin->priv->totem);
 
-	mrl = totem_get_current_mrl (plugin->totem);
-	main_window = totem_get_main_window (plugin->totem);
-	dialog = gtk_file_chooser_dialog_new (_("Open Chapters File"), main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
+	mrl = totem_get_current_mrl (plugin->priv->totem);
+	main_window = totem_get_main_window (plugin->priv->totem);
+	dialog = gtk_file_chooser_dialog_new (_("Open Chapter File"), main_window, GTK_FILE_CHOOSER_ACTION_OPEN,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 					      GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
 					      NULL);
@@ -1058,7 +1011,7 @@ load_button_clicked_cb (GtkButton		*button,
 	}
 
 	if (plugin->priv->was_played)
-		totem_action_play (plugin->totem);
+		totem_action_play (plugin->priv->totem);
 
 	gtk_widget_destroy (dialog);
 	g_object_unref (main_window);
@@ -1100,13 +1053,11 @@ goto_button_clicked_cb (GtkButton		*button,
 	g_list_free (list);
 }
 
-static gboolean
-impl_activate (TotemPlugin *plugin,
-	       TotemObject *totem,
-	       GError **error)
+static void
+impl_activate (PeasActivatable *plugin)
 {
+	TotemObject		*totem;
 	GtkWindow		*main_window;
-	GConfClient		*gconf;
 	GtkBuilder		*builder;
 	GtkWidget		*main_box;
 	GtkTreeSelection	*selection;
@@ -1115,29 +1066,22 @@ impl_activate (TotemPlugin *plugin,
 	GtkTreeViewColumn	*column;
 	gchar			*mrl;
 
-	g_return_val_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin), FALSE);
+	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 
 	cplugin = TOTEM_CHAPTERS_PLUGIN (plugin);
+	totem = g_object_get_data (G_OBJECT (plugin), "object");
 	main_window = totem_get_main_window (totem);
 
-	builder = totem_plugin_load_interface (plugin, "chapters-list.ui", TRUE,
+	builder = totem_plugin_load_interface ("chapters", "chapters-list.ui", TRUE,
 					       main_window, cplugin);
 	g_object_unref (main_window);
 
-	if (builder == NULL) {
-		//FIXME set error
-		return FALSE;
-	}
+	if (builder == NULL)
+		return;
 
-	gconf = gconf_client_get_default ();
-	if (G_LIKELY (gconf != NULL)) {
-		cplugin->priv->autoload = gconf_client_get_bool (gconf, GCONF_PREFIX"/autoload_chapters", NULL);
-		cplugin->priv->autoload_handle_id = gconf_client_notify_add (gconf, GCONF_PREFIX"/autoload_chapters",
-									     (GConfClientNotifyFunc) gconf_autoload_changed_cb,
-									      cplugin, NULL, NULL);
-	} else
-		cplugin->priv->autoload = TRUE;
-	cplugin->priv->gconf = gconf;
+	cplugin->priv->settings = g_settings_new (TOTEM_GSETTINGS_SCHEMA);
+	cplugin->priv->autoload = g_settings_get_boolean (cplugin->priv->settings, "autoload-chapters");
+	g_signal_connect (cplugin->priv->settings, "changed::autoload-chapters", (GCallback) autoload_changed_cb, cplugin);
 
 	cplugin->priv->tree = GTK_WIDGET (gtk_builder_get_object (builder, "chapters_tree_view"));
 	cplugin->priv->action_group = GTK_ACTION_GROUP (gtk_builder_get_object (builder, "chapters-action-group"));
@@ -1146,7 +1090,7 @@ impl_activate (TotemPlugin *plugin,
 	g_object_ref (cplugin->priv->ui_manager);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
-	column = gtk_tree_view_column_new_with_attributes ("Pixbuf", renderer, "pixbuf", CHAPTERS_PIXBUF_COLUMN, NULL);
+	column = gtk_tree_view_column_new_with_attributes (_("Chapter Screenshot"), renderer, "pixbuf", CHAPTERS_PIXBUF_COLUMN, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (cplugin->priv->tree), column);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -1157,16 +1101,16 @@ impl_activate (TotemPlugin *plugin,
 	g_signal_connect (G_OBJECT (renderer), "edited",
 			  G_CALLBACK (finish_chapter_edit), cplugin);
 
-	column = gtk_tree_view_column_new_with_attributes ("Title", renderer,
+	column = gtk_tree_view_column_new_with_attributes (_("Chapter Title"), renderer,
 							   "markup", CHAPTERS_TITLE_COLUMN, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (cplugin->priv->tree), column);
 
-	cplugin->totem = g_object_ref (totem);
+	cplugin->priv->totem = g_object_ref (totem);
 	/* for read operation */
 	cplugin->priv->cancellable[0] = NULL;
 	/* for write operation */
 	cplugin->priv->cancellable[1] = NULL;
-	cplugin->edit_chapter = NULL;
+	cplugin->priv->edit_chapter = NULL;
 	cplugin->priv->last_frame = NULL;
 	cplugin->priv->cmml_mrl = NULL;
 	cplugin->priv->last_time = 0;
@@ -1184,9 +1128,11 @@ impl_activate (TotemPlugin *plugin,
 	cplugin->priv->list_box = GTK_WIDGET (gtk_builder_get_object (builder, "main_vbox"));
 	cplugin->priv->load_box = GTK_WIDGET (gtk_builder_get_object (builder, "load_vbox"));
 
-	main_box = gtk_vbox_new (FALSE, 6);
+	main_box = gtk_box_new (FALSE, 6);
+	gtk_orientable_set_orientation (GTK_ORIENTABLE (main_box), GTK_ORIENTATION_VERTICAL);
 	gtk_box_pack_start (GTK_BOX (main_box), cplugin->priv->list_box, TRUE, TRUE, 0);
 	gtk_box_pack_start (GTK_BOX (main_box), cplugin->priv->load_box, TRUE, TRUE, 0);
+	gtk_widget_show_all (main_box);
 
 	set_no_data_visible (TRUE, FALSE, cplugin);
 
@@ -1208,26 +1154,56 @@ impl_activate (TotemPlugin *plugin,
 			  G_CALLBACK (chapter_selection_changed_cb),
 			  plugin);
 
-	mrl = totem_get_current_mrl (cplugin->totem);
+	mrl = totem_get_current_mrl (cplugin->priv->totem);
 	if (mrl != NULL)
-		totem_file_opened_async_cb (cplugin->totem, mrl, cplugin);
+		totem_file_opened_async_cb (cplugin->priv->totem, mrl, cplugin);
 
 	g_object_unref (builder);
 	g_free (mrl);
-
-	return TRUE;
 }
 
 static void
-impl_deactivate (TotemPlugin *plugin,
-		 TotemObject *totem)
+impl_deactivate (PeasActivatable *plugin)
 {
+	TotemObject		*totem;
 	TotemChaptersPlugin	*cplugin;
 
 	g_return_if_fail (TOTEM_IS_CHAPTERS_PLUGIN (plugin));
 
+	totem = g_object_get_data (G_OBJECT (plugin), "object");
 	cplugin = TOTEM_CHAPTERS_PLUGIN (plugin);
 
+	/* If there are unsaved changes to the chapter data, ask the user if they'd like to save them. */
+	if (gtk_widget_get_sensitive (cplugin->priv->save_button) == TRUE) {
+		GtkWidget *dialog;
+		GtkWindow *main_window;
+
+		main_window = totem_object_get_main_window (totem);
+		dialog = gtk_message_dialog_new (main_window, GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+		                                 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+		                                 _("Save changes to chapter list before closing?"));
+		g_object_unref (main_window);
+
+		gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+		                        /* Translators: close Totem without saving changes to the chapter list of the current movie. */
+		                        _("Close without Saving"), GTK_RESPONSE_CLOSE,
+		                        /* Translators: save changes to the chapter list of the current movie before closing Totem. */
+		                        _("Save"), GTK_RESPONSE_OK,
+		                        NULL);
+		gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+		                                          _("If you don't save, changes to the chapter list will be lost."));
+
+		if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK) {
+			/* Save the chapter list before closing */
+			save_button_clicked_cb (GTK_BUTTON (cplugin->priv->save_button), cplugin);
+
+			/* Prevent it being cancelled further down in this function */
+			cplugin->priv->cancellable[1] = NULL;
+		}
+
+		gtk_widget_destroy (dialog);
+	}
+
 	/* FIXME: do not cancel async operation if any */
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (totem),
@@ -1236,16 +1212,14 @@ impl_deactivate (TotemPlugin *plugin,
 	g_signal_handlers_disconnect_by_func (G_OBJECT (totem),
 					      totem_file_closed_cb,
 					      plugin);
-	if (cplugin->priv->gconf != NULL) {
-		gconf_client_notify_remove (cplugin->priv->gconf, cplugin->priv->autoload_handle_id);
-		g_object_unref (cplugin->priv->gconf);
-	}
+	if (cplugin->priv->settings != NULL)
+		g_object_unref (cplugin->priv->settings);
 
 	if (G_UNLIKELY (cplugin->priv->last_frame != NULL))
 		g_object_unref (G_OBJECT (cplugin->priv->last_frame));
 
-	if (G_UNLIKELY (cplugin->edit_chapter != NULL))
-		gtk_widget_destroy (GTK_WIDGET (cplugin->edit_chapter));
+	if (G_UNLIKELY (cplugin->priv->edit_chapter != NULL))
+		gtk_widget_destroy (GTK_WIDGET (cplugin->priv->edit_chapter));
 
 	if (G_LIKELY (cplugin->priv->action_group != NULL))
 		g_object_unref (cplugin->priv->action_group);
@@ -1260,7 +1234,7 @@ impl_deactivate (TotemPlugin *plugin,
 		g_cancellable_cancel (cplugin->priv->cancellable[1]);
 
 
-	g_object_unref (cplugin->totem);
+	g_object_unref (cplugin->priv->totem);
 	g_free (cplugin->priv->cmml_mrl);
 
 	totem_remove_sidebar_page (totem, "chapters");
