@@ -35,7 +35,10 @@ void totem_sublang_exit (Totem *totem);
 void totem_setup_play_disc (Totem *totem);
 
 void totem_setup_recent (Totem *totem);
-void totem_action_add_recent (Totem *totem, const char *uri);
+void totem_action_add_recent (Totem      *totem,
+			      const char *uri,
+			      const char *display_name,
+			      const char *content_type);
 
 G_END_DECLS
 
