@@ -161,6 +161,33 @@ error_handler (GstBus *bus,
 		exit (1);
 	case GST_MESSAGE_EOS:
 		exit (0);
+
+	case GST_MESSAGE_UNKNOWN:
+	case GST_MESSAGE_WARNING:
+	case GST_MESSAGE_INFO:
+	case GST_MESSAGE_TAG:
+	case GST_MESSAGE_BUFFERING:
+	case GST_MESSAGE_STATE_CHANGED:
+	case GST_MESSAGE_STATE_DIRTY:
+	case GST_MESSAGE_STEP_DONE:
+	case GST_MESSAGE_CLOCK_PROVIDE:
+	case GST_MESSAGE_CLOCK_LOST:
+	case GST_MESSAGE_NEW_CLOCK:
+	case GST_MESSAGE_STRUCTURE_CHANGE:
+	case GST_MESSAGE_STREAM_STATUS:
+	case GST_MESSAGE_APPLICATION:
+	case GST_MESSAGE_ELEMENT:
+	case GST_MESSAGE_SEGMENT_START:
+	case GST_MESSAGE_SEGMENT_DONE:
+	case GST_MESSAGE_DURATION:
+	case GST_MESSAGE_LATENCY:
+	case GST_MESSAGE_ASYNC_START:
+	case GST_MESSAGE_ASYNC_DONE:
+	case GST_MESSAGE_REQUEST_STATE:
+	case GST_MESSAGE_STEP_START:
+	case GST_MESSAGE_QOS:
+	case GST_MESSAGE_PROGRESS:
+	case GST_MESSAGE_ANY:
 	default:
 		/* Ignored */
 		;;
@@ -268,8 +295,36 @@ thumb_app_start (ThumbApp *app)
 		case GST_MESSAGE_ERROR:
 			totem_gst_message_print (message, app->play, "totem-video-thumbnailer-error");
 			break;
+
+		case GST_MESSAGE_UNKNOWN:
+		case GST_MESSAGE_EOS:
+		case GST_MESSAGE_WARNING:
+		case GST_MESSAGE_INFO:
+		case GST_MESSAGE_TAG:
+		case GST_MESSAGE_BUFFERING:
+		case GST_MESSAGE_STATE_CHANGED:
+		case GST_MESSAGE_STATE_DIRTY:
+		case GST_MESSAGE_STEP_DONE:
+		case GST_MESSAGE_CLOCK_PROVIDE:
+		case GST_MESSAGE_CLOCK_LOST:
+		case GST_MESSAGE_NEW_CLOCK:
+		case GST_MESSAGE_STRUCTURE_CHANGE:
+		case GST_MESSAGE_STREAM_STATUS:
+		case GST_MESSAGE_APPLICATION:
+		case GST_MESSAGE_ELEMENT:
+		case GST_MESSAGE_SEGMENT_START:
+		case GST_MESSAGE_SEGMENT_DONE:
+		case GST_MESSAGE_DURATION:
+		case GST_MESSAGE_LATENCY:
+		case GST_MESSAGE_ASYNC_START:
+		case GST_MESSAGE_REQUEST_STATE:
+		case GST_MESSAGE_STEP_START:
+		case GST_MESSAGE_QOS:
+		case GST_MESSAGE_PROGRESS:
+		case GST_MESSAGE_ANY:
 		default:
-			g_assert_not_reached ();
+			/* Ignore */
+			;;
 		}
 
 		gst_message_unref (message);
@@ -1000,7 +1055,7 @@ int main (int argc, char *argv[])
 	if (gallery == -1)
 		thumb_app_check_for_cover (&app);
 	if (thumb_app_get_has_video (&app) == FALSE) {
-		g_print ("totem-video-thumbnailer couldn't find a video track in '%s'\n", input);
+		g_debug ("totem-video-thumbnailer couldn't find a video track in '%s'\n", input);
 		exit (1);
 	}
 	if (thumb_app_set_duration (&app) == FALSE) {
